==> estateplat-common-1.2.3-20180726.081216-154-sources.jar: cn/gtmap/estateplat/model/stockHouse/contract/FcjyClfCsgpFwgk.java <==
package cn.gtmap.estateplat.model.stockHouse.contract;

import java.util.Date;

@javax.persistence.Table(name = "fcjy_clf_csgpfwgk")

public class FcjyClfCsgpFwgk implements cn.gtmap.estateplat.model.server.core.InsertVo{
    @javax.persistence.Id
    private String id;// id
    private String hbh;// 户编号
    private String fbzl;//发布坐落
    private String xqmc;//小区名称
    private String hx;//户型
    private Double rjl;//容积率
    private String fxt;//房型图
    private String jgt;//景观图
    private String lc;//楼层
    private String cx;//朝向
    private String zxcd;//装修程度
    private String fwzscl;//房屋装饰处理
    private String wxzjjsfs;//维修资金结算方式
    private String mjgc;//面积构成
    private String ptss;//配套设施
    private Date jfrq;//交房日期
    private String dzyzk;//带租约状况
    private Double jzmj;//建筑面积
    private Double ftmj ;//分摊面积
    private String fwjg;//房屋结构
    private String fwlx;//房屋类型
    private String szc;//所在层
    private String zcs;//总层数
    private String cqzh;//产权证号
    private String jcnf;//建成年份
    private String xmly;//项目来源
    private Double symj;//使用面积
    private String ghyt;//规划用途
    private String fwxz;//房屋性质
    private String csgpid;//挂牌id
    private Long csgpbh;//挂牌编号

    private String yfwlx;//原房屋类型
    private String yfwjg;//原房屋结构
    private String yghyt;//原规划用途
    private String yfwxz;//原房屋性质

    private String tdsyqr;//土地使用权人
    private String tdsyqzh;//土地使用权证号
    private String tdsyqlx;//土地使用权类型
    private Double fttdmj;//分摊土地面积
    private Double dytdmj;//独用土地面积
    private Double zdmj;//土地使用权面积

    public String getTdsyqr() {
        return tdsyqr;
    }

    public void setTdsyqr(String tdsyqr) {
        this.tdsyqr = tdsyqr;
    }

    public String getTdsyqzh() {
        return tdsyqzh;
    }

    public void setTdsyqzh(String tdsyqzh) {
        this.tdsyqzh = tdsyqzh;
    }

    public String getTdsyqlx() {
        return tdsyqlx;
    }

    public void setTdsyqlx(String tdsyqlx) {
        this.tdsyqlx = tdsyqlx;
    }

    public Double getFttdmj() {
        return fttdmj;
    }

    public void setFttdmj(Double fttdmj) {
        this.fttdmj = fttdmj;
    }

    public Double getDytdmj() {
        return dytdmj;
    }

    public void setDytdmj(Double dytdmj) {
        this.dytdmj = dytdmj;
    }

    public Double getZdmj() {
        return zdmj;
    }

    public void setZdmj(Double zdmj) {
        this.zdmj = zdmj;
    }

    public String getYfwlx() {
        return yfwlx;
    }

    public void setYfwlx(String yfwlx) {
        this.yfwlx = yfwlx;
    }

    public String getYfwjg() {
        return yfwjg;
    }

    public void setYfwjg(String yfwjg) {
        this.yfwjg = yfwjg;
    }

    public String getYghyt() {
        return yghyt;
    }

    public void setYghyt(String yghyt) {
        this.yghyt = yghyt;
    }

    public String getYfwxz() {
        return yfwxz;
    }

    public void setYfwxz(String yfwxz) {
        this.yfwxz = yfwxz;
    }




    public String getCsgpid() {
        return csgpid;
    }

    public void setCsgpid(String csgpid) {
        this.csgpid = csgpid;
    }

    public Long getCsgpbh() {
        return csgpbh;
    }

    public void setCsgpbh(Long csgpbh) {
        this.csgpbh = csgpbh;
    }

    public String getId() {
        return id;
    }

    public void setId(String id) {
        this.id = id;
    }

    public String getHbh() {
        return hbh;
    }

    public void setHbh(String hbh) {
        this.hbh = hbh;
    }

    public String getFbzl() {
        return fbzl;
    }

    public void setFbzl(String fbzl) {
        this.fbzl = fbzl;
    }

    public String getXqmc() {
        return xqmc;
    }

    public void setXqmc(String xqmc) {
        this.xqmc = xqmc;
    }

    public String getHx() {
        return hx;
    }

    public void setHx(String hx) {
        this.hx = hx;
    }

    public Double getRjl() {
        return rjl;
    }

    public void setRjl(Double rjl) {
        this.rjl = rjl;
    }

    public String getFxt() {
        return fxt;
    }

    public void setFxt(String fxt) {
        this.fxt = fxt;
    }

    public String getJgt() {
        return jgt;
    }

    public void setJgt(String jgt) {
        this.jgt = jgt;
    }

    public String getLc() {
        return lc;
    }

    public void setLc(String lc) {
        this.lc = lc;
    }

    public String getCx() {
        return cx;
    }

    public void setCx(String cx) {
        this.cx = cx;
    }

    public String getZxcd() {
        return zxcd;
    }

    public void setZxcd(String zxcd) {
        this.zxcd = zxcd;
    }

    public String getFwzscl() {
        return fwzscl;
    }

    public void setFwzscl(String fwzscl) {
        this.fwzscl = fwzscl;
    }

    public String getWxzjjsfs() {
        return wxzjjsfs;
    }

    public void setWxzjjsfs(String wxzjjsfs) {
        this.wxzjjsfs = wxzjjsfs;
    }

    public String getMjgc() {
        return mjgc;
    }

    public void setMjgc(String mjgc) {
        this.mjgc = mjgc;
    }

    public String getPtss() {
        return ptss;
    }

    public void setPtss(String ptss) {
        this.ptss = ptss;
    }

    public Date getJfrq() {
        return jfrq;
    }

    public void setJfrq(Date jfrq) {
        this.jfrq = jfrq;
    }

    public String getDzyzk() {
        return dzyzk;
    }

    public void setDzyzk(String dzyzk) {
        this.dzyzk = dzyzk;
    }

    public Double getJzmj() {
        return jzmj;
    }

    public void setJzmj(Double jzmj) {
        this.jzmj = jzmj;
    }

    public Double getFtmj() {
        return ftmj;
    }

    public void setFtmj(Double ftmj) {
        this.ftmj = ftmj;
    }

    public String getFwjg() {
        return fwjg;
    }

    public void setFwjg(String fwjg) {
        this.fwjg = fwjg;
    }

    public String getFwlx() {
        return fwlx;
    }

    public void setFwlx(String fwlx) {
        this.fwlx = fwlx;
    }

    public String getSzc() {
        return szc;
    }

    public void setSzc(String szc) {
        this.szc = szc;
    }

    public String getZcs() {
        return zcs;
    }

    public void setZcs(String zcs) {
        this.zcs = zcs;
    }

    public String getCqzh() {
        return cqzh;
    }

    public void setCqzh(String cqzh) {
        this.cqzh = cqzh;
    }

    public String getJcnf() {
        return jcnf;
    }

    public void setJcnf(String jcnf) {
        this.jcnf = jcnf;
    }

    public String getXmly() {
        return xmly;
    }

    public void setXmly(String xmly) {
        this.xmly = xmly;
    }

    public Double getSymj() {
        return symj;
    }

    public void setSymj(Double symj) {
        this.symj = symj;
    }

    public String getGhyt() {
        return ghyt;
    }

    public void setGhyt(String ghyt) {
        this.ghyt = ghyt;
    }

    public String getFwxz() {
        return fwxz;
    }

    public void setFwxz(String fwxz) {
        this.fwxz = fwxz;
    }
}

==> estateplat-common-1.2.3-20190417.024543-235-sources.jar: cn/gtmap/estateplat/model/stockHouse/contract/FcjyClfCsgpFwgk.java <==
package cn.gtmap.estateplat.model.stockHouse.contract;

import cn.gtmap.estateplat.model.server.core.InsertVo;

import java.util.Date;

@javax.persistence.Table(name = "fcjy_clf_csgpfwgk")

public class FcjyClfCsgpFwgk implements InsertVo {
    @javax.persistence.Id
    private String id;// id
    private String hbh;// 户编号
    private String fbzl;//发布坐落
    private String xqmc;//小区名称
    private String hx;//户型
    private Double rjl;//容积率
    private String fxt;//房型图
    private String jgt;//景观图
    private String lc;//楼层
    private String cx;//朝向
    private String zxcd;//装修程度
    private String fwzscl;//房屋装饰处理
    private String wxzjjsfs;//维修资金结算方式
    private String mjgc;//面积构成
    private String ptss;//配套设施
    private Date jfrq;//交房日期
    private String dzyzk;//带租约状况
    private Double jzmj;//建筑面积
    private Double ftmj ;//分摊面积
    private String fwjg;//房屋结构
    private String fwlx;//房屋类型
    private String szc;//所在层
    private String zcs;//总层数
    private String cqzh;//产权证号
    private String jcnf;//建成年份
    private String xmly;//项目来源
    private Double symj;//使用面积
    private String ghyt;//规划用途
    private String fwxz;//房屋性质
    private String csgpid;//挂牌id
    private Long csgpbh;//挂牌编号

    private String yfwlx;//原房屋类型
    private String yfwjg;//原房屋结构
    private String yghyt;//原规划用途
    private String yfwxz;//原房屋性质

    private String tdsyqr;//土地使用权人
    private String tdsyqzh;//土地使用权证号
    private String tdsyqlx;//土地使用权类型
    private Double fttdmj;//分摊土地面积
    private Double dytdmj;//独用土地面积
    private Double zdmj;//土地使用权面积

    public String getTdsyqr() {
        return tdsyqr;
    }

    public void setTdsyqr(String tdsyqr) {
        this.tdsyqr = tdsyqr;
    }

    public String getTdsyqzh() {
        return tdsyqzh;
    }

    public void setTdsyqzh(String tdsyqzh) {
        this.tdsyqzh = tdsyqzh;
    }

    public String getTdsyqlx() {
        return tdsyqlx;
    }

    public void setTdsyqlx(String tdsyqlx) {
        this.tdsyqlx = tdsyqlx;
    }

    public Double getFttdmj() {
        return fttdmj;
    }

    public void setFttdmj(Double fttdmj) {
        this.fttdmj = fttdmj;
    }

    public Double getDytdmj() {
        return dytdmj;
    }

    public void setDytdmj(Double dytdmj) {
        this.dytdmj = dytdmj;
    }

    public Double getZdmj() {
        return zdmj;
    }

    public void setZdmj(Double zdmj) {
        this.zdmj = zdmj;
    }

    public String getYfwlx() {
        return yfwlx;
    }

    public void setYfwlx(String yfwlx) {
        this.yfwlx = yfwlx;
    }

    public String getYfwjg() {
        return yfwjg;
    }

    public void setYfwjg(String yfwjg) {
        this.yfwjg = yfwjg;
    }

    public String getYghyt() {
        return yghyt;
    }

    public void setYghyt(String yghyt) {
        this.yghyt = yghyt;
    }

    public String getYfwxz() {
        return yfwxz;
    }

    public void setYfwxz(String yfwxz) {
        this.yfwxz = yfwxz;
    }




    public String getCsgpid() {
        return csgpid;
    }

    public void setCsgpid(String csgpid) {
        this.csgpid = csgpid;
    }

    public Long getCsgpbh() {
        return csgpbh;
    }

    public void setCsgpbh(Long csgpbh) {
        this.csgpbh = csgpbh;
    }

    public String getId() {
        return id;
    }

    public void setId(String id) {
        this.id = id;
    }

    public String getHbh() {
        return hbh;
    }

    public void setHbh(String hbh) {
        this.hbh = hbh;
    }

    public String getFbzl() {
        return fbzl;
    }

    public void setFbzl(String fbzl) {
        this.fbzl = fbzl;
    }

    public String getXqmc() {
        return xqmc;
    }

    public void setXqmc(String xqmc) {
        this.xqmc = xqmc;
    }

    public String getHx() {
        return hx;
    }

    public void setHx(String hx) {
        this.hx = hx;
    }

    public Double getRjl() {
        return rjl;
    }

    public void setRjl(Double rjl) {
        this.rjl = rjl;
    }

    public String getFxt() {
        return fxt;
    }

    public void setFxt(String fxt) {
        this.fxt = fxt;
    }

    public String getJgt() {
        return jgt;
    }

    public void setJgt(String jgt) {
        this.jgt = jgt;
    }

    public String getLc() {
        return lc;
    }

    public void setLc(String lc) {
        this.lc = lc;
    }

    public String getCx() {
        return cx;
    }

    public void setCx(String cx) {
        this.cx = cx;
    }

    public String getZxcd() {
        return zxcd;
    }

    public void setZxcd(String zxcd) {
        this.zxcd = zxcd;
    }

    public String getFwzscl() {
        return fwzscl;
    }

    public void setFwzscl(String fwzscl) {
        this.fwzscl = fwzscl;
    }

    public String getWxzjjsfs() {
        return wxzjjsfs;
    }

    public void setWxzjjsfs(String wxzjjsfs) {
        this.wxzjjsfs = wxzjjsfs;
    }

    public String getMjgc() {
        return mjgc;
    }

    public void setMjgc(String mjgc) {
        this.mjgc = mjgc;
    }

    public String getPtss() {
        return ptss;
    }

    public void setPtss(String ptss) {
        this.ptss = ptss;
    }

    public Date getJfrq() {
        return jfrq;
    }

    public void setJfrq(Date jfrq) {
        this.jfrq = jfrq;
    }

    public String getDzyzk() {
        return dzyzk;
    }

    public void setDzyzk(String dzyzk) {
        this.dzyzk = dzyzk;
    }

    public Double getJzmj() {
        return jzmj;
    }

    public void setJzmj(Double jzmj) {
        this.jzmj = jzmj;
    }

    public Double getFtmj() {
        return ftmj;
    }

    public void setFtmj(Double ftmj) {
        this.ftmj = ftmj;
    }

    public String getFwjg() {
        return fwjg;
    }

    public void setFwjg(String fwjg) {
        this.fwjg = fwjg;
    }

    public String getFwlx() {
        return fwlx;
    }

    public void setFwlx(String fwlx) {
        this.fwlx = fwlx;
    }

    public String getSzc() {
        return szc;
    }

    public void setSzc(String szc) {
        this.szc = szc;
    }

    public String getZcs() {
        return zcs;
    }

    public void setZcs(String zcs) {
        this.zcs = zcs;
    }

    public String getCqzh() {
        return cqzh;
    }

    public void setCqzh(String cqzh) {
        this.cqzh = cqzh;
    }

    public String getJcnf() {
        return jcnf;
    }

    public void setJcnf(String jcnf) {
        this.jcnf = jcnf;
    }

    public String getXmly() {
        return xmly;
    }

    public void setXmly(String xmly) {
        this.xmly = xmly;
    }

    public Double getSymj() {
        return symj;
    }

    public void setSymj(Double symj) {
        this.symj = symj;
    }

    public String getGhyt() {
        return ghyt;
    }

    public void setGhyt(String ghyt) {
        this.ghyt = ghyt;
    }

    public String getFwxz() {
        return fwxz;
    }

    public void setFwxz(String fwxz) {
        this.fwxz = fwxz;
    }
}
